package com.sun.jndi.ldap;

import sun.misc.SharedSecrets;
import java.security.AccessControlContext;
import java.security.AccessController;
import java.security.PrivilegedAction;
import java.net.MalformedURLException;
import java.net.URLClassLoader;

final class VersionHelper12 extends VersionHelper
{
    private static final String TRUST_URL_CODEBASE_PROPERTY = "com.sun.jndi.ldap.object.trustURLCodebase";
    private static final String trustURLCodebase;
    
    VersionHelper12() {
    }
    
    @Override
    ClassLoader getURLClassLoader(String[] array) throws MalformedURLException {
        ClassLoader contextClassLoader = this.getContextClassLoader();
        if (array != null && "true".equalsIgnoreCase(VersionHelper12.trustURLCodebase)) {
            return URLClassLoader.newInstance(VersionHelper.getUrlArray(array), contextClassLoader);
        }
        return contextClassLoader;
    }
    
    @Override
    Class<?> loadClass(String name) throws ClassNotFoundException {
        return Class.forName(name, true, this.getContextClassLoader());
    }
    
    private ClassLoader getContextClassLoader() {
        return (ClassLoader)AccessController.doPrivileged(new PrivilegedAction<ClassLoader>() {
            @Override
            public ClassLoader run() {
                return Thread.currentThread().getContextClassLoader();
            }
        });
    }
    
    @Override
    Thread createThread(final Runnable runnable) {
        return (Thread)AccessController.doPrivileged(new PrivilegedAction<Thread>() {
            
            @Override
            public Thread run() {
                return SharedSecrets.getJavaLangAccess().newThreadWithAcc(runnable, acc);
            }
        });
    }
    
    static {
        trustURLCodebase = (String)AccessController.doPrivileged(new PrivilegedAction<String>() {
            @Override
            public String run() {
                return System.getProperty("com.sun.jndi.ldap.object.trustURLCodebase", "false");
            }
        });
    }
}
